<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Data generator class for mod_subsection.
 *
 * @package    mod_subsection
 * @category   test
 * @copyright  2023 Ferran Recio <ferran@moodle.com>
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
class mod_subsection_generator extends testing_module_generator {
    #[\Override]
    public function create_instance($record = null, ?array $options = null): stdClass {
        global $DB;

        // Ensure the record can be modified without affecting calling code.
        $record = (object)(array)$record;

        // Create the subsection instance.
        $instance = parent::create_instance($record, (array)$options);

        // Update the delegated section summary if needed.
        if (isset($record->summary)) {
            $DB->set_field(
                'course_sections',
                'summary',
                $record->summary,
                [
                    'component' => 'mod_subsection',
                    'itemid' => $instance->id,
                ],
            );
        }

        return $instance;
    }
}
