{{!
    This file is part of Moodle - http://moodle.org/

    Moodle is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Moodle is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
}}
{{!
    @template core_ai/admin_add_provider

    Template to display a call to action to create new AI providers.

    Context variables required for this template:
    * addnewproviderurl - URL to the AI provider setup page.

    Example context (json):
    {
        "addnewproviderurl": "http://example.com"
    }
}}

<div class="d-flex flex-row-reverse">
    <a href="{{addnewproviderurl}}" title="{{#str}}createnewprovider, core_ai{{/str}}" class="btn btn-primary mb-3">
        <i class="fa fa-plus"></i>&nbsp;{{#str}}createnewprovider, core_ai{{/str}}
    </a>
</div>
